==> osmo-e1d_0.2.1.tar.xz: BUILD/README.md <==
osmo-e1d - Osmocom E1 interface daemon
======================================

This repository contains the osmocom E1 interface daemon,
a pure userspace driver for the icE1usb hardware USB E1 adapter.

It is part of the [Osmocom](https://osmocom.org/) Open Source Mobile
Communications project.

Homepage
--------

The official homepage of the project is
https://osmocom.org/projects/osmo-e1d/wiki

GIT Repository
--------------

You can clone from the official osmo-e1d.git repository using

	git clone git://git.osmocom.org/osmo-e1d.git
	git clone https://git.osmocom.org/osmo-e1d.git

There is a cgit interface at https://git.osmocom.org/osmo-e1d/

Related Links
-------------

* [icE1usb USB E1 adapter](https://osmocom.org/projects/e1-t1-adapter/wiki/IcE1usb)
* [alternative DAHDI driver](https://osmocom.org/issues/4923)

Mailing List
------------

Discussions related to osmo-e1d are happening on the
openbsc@lists.osmocom.org mailing list, please see
https://lists.osmocom.org/mailman/listinfo/openbsc for subscription
options and the list archive.

Please observe the [Osmocom Mailing List
Rules](https://osmocom.org/projects/cellular-infrastructure/wiki/Mailing_List_Rules)
when posting.

Contributing
------------

Our coding standards are described at
https://osmocom.org/projects/cellular-infrastructure/wiki/Coding_standards

We us a gerrit based patch submission/review process for managing
contributions.  Please see
https://osmocom.org/projects/cellular-infrastructure/wiki/Gerrit for
more details

The current patch queue for osmo-e1d can be seen at
https://gerrit.osmocom.org/#/q/project:osmo-e1d+status:open

==> osmo-e1d_0.6.0.tar.xz: BUILD/README.md <==
osmo-e1d - Osmocom E1 interface daemon
======================================

This repository contains the osmocom E1 interface daemon,
a pure userspace driver for the icE1usb hardware USB E1 adapter.

It is part of the [Osmocom](https://osmocom.org/) Open Source Mobile
Communications project.

Homepage
--------

The official homepage of the project is
<https://osmocom.org/projects/osmo-e1d/wiki>

GIT Repository
--------------

You can clone from the official osmo-e1d.git repository using

	git clone https://gitea.osmocom.org/retronetworking/osmo-e1d

There is a web interface at <https://gitea.osmocom.org/retronetworking/osmo-e1d>

Related Links
-------------

* [icE1usb USB E1 adapter](https://osmocom.org/projects/e1-t1-adapter/wiki/IcE1usb)
* [alternative DAHDI driver](https://osmocom.org/issues/4923)

Mailing List
------------

Discussions related to osmo-e1d are happening on the
openbsc@lists.osmocom.org mailing list, please see
https://lists.osmocom.org/mailman/listinfo/openbsc for subscription
options and the list archive.

Please observe the [Osmocom Mailing List
Rules](https://osmocom.org/projects/cellular-infrastructure/wiki/Mailing_List_Rules)
when posting.

Contributing
------------

Our coding standards are described at
<https://osmocom.org/projects/cellular-infrastructure/wiki/Coding_standards>

We us a gerrit based patch submission/review process for managing
contributions.  Please see
<https://osmocom.org/projects/cellular-infrastructure/wiki/Gerrit> for
more details

The current patch queue for osmo-e1d can be seen at
<https://gerrit.osmocom.org/#/q/project:osmo-e1d+status:open>
